#
# spec file for package minigalaxy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           minigalaxy
Version:        1.3.1
Release:        1.1
Summary:        A GOG client for Linux that lets you download and play your GOG Linux games
License:        GPL-3.0-only
Group:          Amusements/Games/Other
URL:            https://github.com/sharkwouter/minigalaxy
Source0:        https://github.com/sharkwouter/minigalaxy/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         minigalaxy-0.9.0-desktop.patch
BuildRequires:  gobject-introspection
BuildRequires:  python3
BuildRequires:  python3-setuptools
Requires:       python3-gobject >= 3.30
Requires:       python3-gobject-Gdk
Requires:       python3-requests
BuildArch:      noarch

%description
A GOG client for Linux that lets you download and play your GOG Linux games.

%prep
%autosetup -p1

%build
%python3_build

%install
%python3_install

rm -rf %{buildroot}%{python3_sitelib}/tests/

%files
%doc README.md
%license LICENSE
%{_bindir}/minigalaxy
%{_datadir}/minigalaxy/
%dir %{_datadir}/icons
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/???x???/
%{_datadir}/applications/io.github.sharkwouter.Minigalaxy.desktop
%{_datadir}/icons/hicolor/???x???/apps/
%{_datadir}/metainfo/io.github.sharkwouter.Minigalaxy.metainfo.xml
%{python3_sitelib}/{m,M}inigalaxy*

%changelog
* Wed Nov 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.3.1:
  * Fix Windows games with multiple parts not installing with wine
  * Minor AppData fixes
  * Added Portuguese translation
* Tue Jun 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.3.0:
  * Fix Remove forward slash from desktop filename for Shenzhen I/O
  * Fix race when preparing download location
  * Fix multithreaded downloads of Windows games
  * Fix DLC installation for Windows games
  * Allow users to specify the download directory
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Sat Jan 20 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to 1.2.6:
  * Fix changing the install path causing an exception
  * Fix error detection & reporting on wineprefix creation failure
- Add group tag
* Fri Aug 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.2.5:
  * Fix short freeze on startup
  * Fix game information not showing in list view
  * Hide A Plague Tale Digital Goodies Pack
  * Remove round corners from top of the "play" button
  * Move the Gametile menu button alongside the Play button
  * Update Spanish translation
  * Capitalize first letter of the "play/download/..." button
  * Update Traditional Chinese translation
  * Added additional tooltips to buttons, labels, menu items and radio buttons
  * Hide CDPR Goodie Pack Content
  * Add notifications on successful download and installation of games
  * Add category filtering dialog for game library
  * Parallelize api.can_connect function with threads, futures
  * Fix available disk space being checked in parent directory
  * Create new config if reading it fails
* Fri Aug 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.2.3:
  * Fix short freeze on startup
  * Fix game information not showing in list view
  * Hide A Plague Tale Digital Goodies Pack
  * Remove round corners from top of the "play" button
  * Move the Gametile menu button alongside the Play button
  * Update Spanish translation
  * Capitalize first letter of the "play/download/..." button
  * Update Traditional Chinese translation
  * Added additional tooltips to buttons, labels, menu items and radio buttons
  * Hide CDPR Goodie Pack Content
  * Add notifications on successful download and installation of games
  * Add category filtering dialog for game library
  * Parallelize api.can_connect function with threads, futures
  * Fix available disk space being checked in parent directory
  * Create new config if reading it fails
* Tue Sep 27 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.2.2:
  * Fix progress bar not showing up for downloads
  * Fix downloads not being cancellable
  * Fix incompatibility with python 3.6
  * Fix connection error texts
  * Show DLC titles in English
  * Fix version not being updated during a release
  * Update Norwegian Bokmål translation
  * Update Czech translation
* Wed Sep 21 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.2.1:
  * Fix downloads failing when content length is not returned by the server
  * Allow different types of downloads to happen at the same time
  * Fix metadata file having releases in wrong order
* Wed Sep 21 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.2.0:
  * Split game information and properties into different windows
  * Add list view
  * Allow DLC to be queued up for downloading
  * Fix changing library to a directory with special characters in the name
  * Fix signing in with Facebook
  * Always use cached DLC icons and thumbnails
  * Cache information covers
  * Fix installers not being cleaned up like expected
  * Fix error when opening game properties window when wine is not installed
  * Fix freeze for games generating a lot of output
  * Fix extracting rar based games with innoextract
  * Allow setting wine executable per game
  * Add GameMode support
  * Add MangoHud support
  * Add option to use Winetricks
  * Fix updates not always being detected directly after opening Minigalaxy
  * Fix desktop files generated not always being able to launch
  * Show percentage when hovering over download progress bar
  * Add option to disable update check per game
  * Add forum, GOG Database and PCGamingWiki URLs to game information
  * List genre as unknown in game information when none is found
  * Fix changing installation path causing crashes in rare cases
  * Fall back to English when locale cannot be determined
  * Add gettext to build dependencies
  * Improve error handling upon API errors
  * Fix several issues with launching Windows games from Minigalaxy
  * Fix some games getting stuck on in queue
  * Fix Windows game installation not caring about preferred language
  * Add Greek translation
  * Add Spanish (Spain) translation
  * Add Romanian (Romania) translation
  * Update Norwegian Bokmål translation
  * Update Czech translation
* Wed Nov 17 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Improve integrity check after downloading
  * Show an error showing Windows games cannot be enabled
  * Add properties menu for games where game specific actions can be made like setting launch options and opening the store page
  * Add a disk space check before downloading
  * Use a different color for the play button for installed games
  * Put installed games at the top of the list
  * Store saved installers in ~/GOG Games/installer by default again
  * Remember if the user had the installed filter enabled
  * Extract Windows games in the background if Innoextract is available
  * Extract Windows games in the background
  * Fix installing DLC for Windows games
  * Fix an error showing if the user has no games
  * Add option to hide games
  * Ask user if they are sure when logging out
  * Add a dark theme
  * Run post install script after installation. This fixes Full Throttle Remastered
  * Fix games being shown twice
  * Fix crash when GOG is down
  * Make the language configurable
* Fri Jan 15 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.2:
  * Fix updates sometimes not working
  * Fix some games always showing an update is available
  * Fix DLC not downloading
  * Fix DLC update option not showing up
  * Fix show store page button not showing anymore
  * Fix missing thumbnails not being downloaded for already installed games
  * Fix the login screen crashing in some cases
  * Use the system's icon theme for icons used
* Fri Jan  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.1:
  * Open maximized if the window was maximized when last closed
  * Kept installers are now stored in ~/.cache/minigalaxy/download
  * Fix about window displaying wrong version number
  * Fix show store page button not showing anymore
  * Fix the download manager crashing when an installer has been damaged
    during downloading
  * Fix games showing an update is available while the latest version is
    installed
  * Fix loading the library taking a long time when many games are installed
  * Fix Gex not launching
  * Add the following translations:
  - Swedish
  * Update the following translations:
  - Polish
  - Russian
* Mon Nov 30 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Games can now be updated
  * DLC can now be installed and updated
  * The installed filter now also shows games which are downloading
  * Fix crash on some systems where /usr/bin is linked to /bin
  * Create new config file if old one is unreadable
  * Fix some Windows games not installing because of the directory name used
  * Fix some Windows games like Witcher 3 not launching because of the working directory not being set
  * Clean up installation files for cancelled downloads
  * Fix crash on flaky internet connection
  * Use 755 permissions for all directories created by Minigalaxy
  * Remove cached files when cancelling a download
  * Installed games should no longer be shown twice
  * Add and update translations
* Mon Apr 20 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.9.4:
  * Added Russian and Nynorsk translation
  * Updated existing translations
  * Added support for installing Windows games.
  * Added store page link to game menus.
  * Fixed game directories being created without any spaces in the name.
  * Fixed thumbnails not being downloaded for already installed games.
  * Fixed symlinks to libraries not being created correctly upon installation.
  * Made preparations for a Flathub package.
  * Added all contributors and translators to the about window.
* Wed Mar 11 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.9.3:
  * Added the following translations:
  - German (thanks to BlindJerobine)
  - Turkish (thanks to fuzunspm)
  - Brazilian Portuguese (thanks to EsdrasTarsis)
  - Norwegian Bokmål (thanks to kimmalmo)
  - Polish (thanks to ArturWroblewski)
  - French (thanks to thomansb22)
  * Added option to cancel downloads.
  * Changed the way games are downloaded to a queue instead of
    trying to download everything at once.
  * Added support option to game specific menus which open the
    GOG support page (thanks to BlindJerobine).
  * Ask for confirmation before uninstalling (thanks to Odelpasso).
  * Added option to display FPS in games (thanks to Odelpasso).
  * Downloads can now be resumed after having been cancelled before.
  * Installers are now verified before installing.
  * The active download is now resumed when restarting Minigalaxy.
  * Fixed issue with games not downloading.
* Mon Jan 13 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.9.2:
  Features:
  * Added a button to installed games which allow you to:
    + Uninstall a game.
    + Open the directory in which the game is installed.
  * Added translation support. The following additional
    languages are now supported: Dutch, Taiwanese Mandarin
  * Added offline mode.
  * The system's Dosbox and Scummvm installations are now
    preferred over the ones bundled with games.
  * Improved game detection to check in all directories
    in the installation path.
  * Added the option to keep game installers.
  * Added the option to disable staying logged in.
  * The preferences menu now uses a file picker for setting
    the installation path
  * Startup time has been reduced.
  * Games which aren't installed are now grayed out.
  Bug fixes:
  * Fixed FTL not being able to start.
  * Fixed issue with thumbnails sometimes not fully loading.
  * Fixed potential crash after logging in the first time.
  * Fixed close button on about window not working.
* Sat Dec 28 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.9.1:
  * Fixed crashes and freezes sometimes happening while downloading
    and installing games.
  * Fixed installation failing when the installation directory is
    not on same filesystem as /home.
  * Fixed downloads crashing when the installation directory is
    changed or the refresh button is pressed.
  * Fixed changing installation directory not loading which games
    are installed in the new directory.
  * Fixed copyright file in deb package not being machine readable.
  * Add command line options --help, --version and --reset.
    The reset option will reset the cache and configuration.
- Add additional required packages
- Refresh minigalaxy-0.9.0-desktop.patch
* Fri Dec 27 2019 Michael Vetter <mvetter@suse.com>
- Add min. version to python3-gobject
- Require python3 instead of devel
* Fri Dec 27 2019 Michael Vetter <mvetter@suse.com>
- Initial package minigalaxy 0.9.0 for openSUSE
- Add minigalaxy-0.9.0-desktop.patch
